@@ -3,5 +3,5 @@ from abc import ABCMeta, abstractmethod
 
 class ImagesGateway(metaclass=ABCMeta):
     @abstractmethod
-    def list_images(self) -> str:
-        "list images"
+    def list_images(self, image_to_scan) -> str:
+        "get image to scan"
