@@ -1,28 +1,28 @@
 import requests
 import zipfile
 import json
-from github import Github
+from github import Github, GithubIntegration
 from devsecops_engine_tools.engine_utilities.utils.api_error import ApiError
 
 
 class GithubApi:
-    def __init__(
-            self,
-            personal_access_token: str = ""
-    ):
-        self.__personal_access_token = personal_access_token
 
     def unzip_file(self, zip_file_path, extract_path):
         with zipfile.ZipFile(zip_file_path, "r") as zip_ref:
             zip_ref.extractall(extract_path)
+    
+    def get_installation_access_token(self,private_key,app_id,instalation_id):
+        if private_key:
+            private_key = private_key.replace("\\n", "\n")
+        integration = GithubIntegration(app_id, private_key)
+        access_token = integration.get_access_token(instalation_id)
+        return access_token.token
 
     def download_latest_release_assets(
-        self, owner, repository, download_path="."
-    ):
+        self, owner, repository, token, download_path=".",
+    ):               
         url = f"https://api.github.com/repos/{owner}/{repository}/releases/latest"
-
-        headers = {"Authorization": f"token {self.__personal_access_token}"}
-
+        headers = {"Authorization": f"token {token}", "Accept": "application/vnd.github+json"}
         response = requests.get(url, headers=headers)
 
         if response.status_code == 200:
@@ -32,11 +32,8 @@ class GithubApi:
             for asset in assets:
                 asset_url = asset["url"]
                 asset_name = asset["name"]
-
                 headers.update({"Accept": "application/octet-stream"})
-
                 response = requests.get(asset_url, headers=headers, stream=True)
-
                 if response.status_code == 200:
                     with open(f"{download_path}/{asset_name}", "wb") as file:
                         for chunk in response.iter_content(chunk_size=8192):
@@ -51,9 +48,8 @@ class GithubApi:
                 f"Error getting the assets of the last release. Status code: {response.status_code}"
             )
 
-    def get_github_connection(self):
-        git_client = Github(self.__personal_access_token)
-
+    def get_github_connection(self,personal_access_token):
+        git_client = Github(personal_access_token)
         return git_client
 
     def get_remote_json_config(self, git_client: Github, owner, repository, path):
@@ -65,4 +61,4 @@ class GithubApi:
 
             return content_json
         except Exception as e:
-            raise ApiError("Error getting remote github configuration file: " + str(e))
+            raise ApiError("Error getting remote github configuration file: " + str(e))
\ No newline at end of file
